/*-----------------------------------------------------------------------
esurban_table3.do

Stata do file to replicate table 3 of the article
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

This requires esurban_table2.do to be run before
-----------------------------------------------------------------------*/

* Initialise
clear all
set more off
set matsize 2000
quietly capture log close
log using ../../output/esurban_table3, text replace

* Recover 1st stage coefficients for city indicators from table 2
use ../../output/esurban_table2_premia, clear
* Merge with current size and historical size instrument
merge 1:1 ua_id using ../../otherdata/ua_size, keepusing(size_pop10k size_pop10k_1900)
keep if _merge == 3
gen ln_size = ln(size_pop10k)
gen ln_size1900 = ln(size_pop10k_1900)
drop _merge size_pop10k size_pop10k_1900
* Merge with geographical instruments
merge 1:1 ua_id using ../../otherdata/ua_geog
keep if _merge == 3
gen ln_elevation = ln(avg25k_elevation)
drop _merge avg25k_elevation
order ua_id ua_name
gen ln_size_first = ln_size

* Column (1), 1st stage
reg ln_size ln_size1900 pct25k_fertile pct25k_water pct25k_steep15 ln_elevation roman_roads, robust
est2vec esurban_table3, e(r2 widstat idp jp) vars(ln_size_first ln_size1900 pct25k_fertile pct25k_water pct25k_steep15 ln_elevation roman_roads) name(a)

* Column (2), 2nd stage initial premium
ivreg2 premium_initial (ln_size_first = ln_size1900 pct25k_fertile pct25k_water pct25k_steep15 ln_elevation roman_roads), robust first ffirst endog(ln_size_first)
est2vec esurban_table3, addto(esurban_table3) name(b)

* Column (3), 2nd stage medium premium
ivreg2 premium_medterm (ln_size_first = ln_size1900 pct25k_fertile pct25k_water pct25k_steep15 ln_elevation roman_roads), robust first ffirst endog(ln_size_first)
est2vec esurban_table3, addto(esurban_table3) name(c)

* Label variables for table
label var ln_size "Log city size"
label var ln_size_first "Instrumented log city size"
label var ln_size1900 "Log city size 1900"
label var pct25k_fertile "\% high-quality land within 25km of city centre"
label var pct25k_water "\% water within 25km of city centre"
label var pct25k_steep15 "\% steep terrain within 25km of city centre"
label var ln_elevation "Log mean elevation within 25km of city centre"
label var roman_roads "Roman road rays 25km from city centre"
* Produce LaTeX table
est2texdp esurban_table3, label preserve replace path(../../output/) levels(90 95 99) mark(stars) digits(4) leadzero flexible(0) fancy
erase ../../output/esurban_table3_tbl.dta

log close

