/*-----------------------------------------------------------------------
mcvl_cohort_setup.do

Stata do file used to recreate the panel for
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

Adjusts MCVL data sets for merging process
-----------------------------------------------------------------------*/

foreach num of numlist 1/4 {
  use "../../tmp/mcvl_cdf_2013/affiliates_`num'", clear
  * Generate unique observations by individual, entry date, exit date and firm id
  * Very few cases, non-uniqueness is mainly related to non-uniqueness in cause of dismissal
  egen count = seq(), by (person_id entry_date exit_date firm_id_sec)
  egen max = max(count), by (person_id entry_date exit_date firm_id_sec)
  drop if count != 1 & max > 1
  drop count max
  save "../../tmp/mcvl_affiliates_`num'", replace
}

foreach num of numlist 1/13 {
  use "../../tmp/mcvl_cdf_2013/contribution_`num'", clear
  * Rename MCVL earnings of 'base contributions'
  rename (earnings_jan earnings_feb earnings_mar earnings_apr earnings_may earnings_jun earnings_jul earnings_aug earnings_sep earnings_oct earnings_nov earnings_dec) /*
  */ (earnings_1 earnings_2 earnings_3 earnings_4 earnings_5 earnings_6 earnings_7 earnings_8 earnings_9 earnings_10 earnings_11 earnings_12)
  * Generate unique observations by individual, firm id and year
  * Rare cases of multiple rows
  egen count = seq(), by (person_id firm_id_sec year)
  egen max = max(count), by (person_id firm_id_sec year)
  drop if count != 1 & max > 1
  drop count max
  * Sort and reorder variables
  drop if year < 1980
  sort person_id firm_id_sec year
  save "../../tmp/mcvl_earnings_`num'", replace
}
