/*-----------------------------------------------------------------------
mcvl_merge_tax.do

Stata do file used to recreate the panel for
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

Merges all annual tax data sets
-----------------------------------------------------------------------*/

** Keep relevant variables from tax data sets 2004-2013
foreach num of numlist 2004/2013 {
  use "../../tmp/mcvl_cdf_`num'/tax", clear
  gen year = `num'
  * Drop non-labor incomes
  drop if payment_type == "B" | payment_type == "C" | payment_type == "D" | payment_type == "K" | payment_type == "L" | payment_type == "M"
  * Obtain earnings by worker-firm in the year
  sort person_id firm_id_tax person_province
  egen count = seq(), by (person_id firm_id_tax)
  egen maxcount = max(count), by (person_id firm_id_tax)
  egen double earnings = sum(payment_amount) if maxcount > 1, by (person_id firm_id_tax)
  egen double inkind = sum(payment_inkind) if maxcount > 1, by (person_id firm_id_tax)
  drop if count > 1
  drop count maxcount
  replace earnings = payment_amount if earnings == .
  replace inkind = payment_inkind if inkind == .
  replace earnings = earnings + inkind
  * Keep relevant variables
  keep person_id firm_id_tax person_province year earnings
  sort person_id firm_id_tax
  compress
  save "../../tmp/tax_`num'", replace
}

** Merge all tax temporary tax data sets 2004-2013 
use "../../tmp/tax_2004", clear
append using "../../tmp/tax_2005"
append using "../../tmp/tax_2006"
append using "../../tmp/tax_2007"
append using "../../tmp/tax_2008"
append using "../../tmp/tax_2009"
append using "../../tmp/tax_2010"
append using "../../tmp/tax_2011"
append using "../../tmp/tax_2012"
append using "../../tmp/tax_2013"

* Deflate earnings
merge m:1 year using "../../otherdata/cpi_annual", keepusing(cpi_index2009)
drop if _merge == 2
drop _merge
sort person_id year firm_id_tax
replace earnings = earnings / cpi_index2009
drop cpi_index2009

* Label variables
label var person_id "Individual identifier"
label var firm_id_tax "Firm identifier for matching with tax data"
label var person_province "Province of individual residence in tax data"
label var year "Year"
label var earnings "Total real annual earnings from tax return (in 2009 cents of euro)"
compress
save "../../tmp/tax_all", replace

* Erase temporary data sets
foreach num of numlist 2004/2013 {  
  erase "../../tmp/tax_`num'.dta"
}
